import {request} from '@/libs/request.js'

/**
 * 分页查询Task
 * @param data
 * @returns
 */
export function getTaskByPage(data) {
  return request({
    url: '/task/page',
    method: 'GET',
    data
  })
}

/**
 * 列表查询Task
 * @param data
 * @returns
 */
export function getTaskByList(data) {
  return request({
    url: '/task',
    method: 'GET',
    data
  })
}

/**
 * 列表查询未执行Task
 * @param data
 * @returns
 */
export function getWaitingTaskByList(data) {
  return request({
    url: '/task/waiting',
    method: 'GET',
    data
  })
}

/**
 * 列表查询Task: 50笔
 * @param data
 * @returns
 */
export function getRecentTaskByList(data) {
  return request({
    url: '/task/recent',
    method: 'GET',
    data
  })
}

/**
 * @param taskId
 * @returns
 */
export function getTaskById(taskId) {
  return request({
    url: `/task/${taskId}`,
    method: 'GET'
  })
}

/**
 * 添加Task
 * @param data
 * @returns
 */
export function createTask(data) {
  return request({
    url: `/task/add`,
    method: 'POST',
    data
  })
}

/**
 * 更新Task
 * @param data
 * @returns
 */
export function updateTask(data) {
  return request({
    url: `/task/update`,
    method: 'PUT',
    data
  })
}

/**
 * 删除Task
 * @param taskId
 * @returns
 */
export function deleteTaskById(taskId) {
  return request({
    url: `/task/${taskId}`,
    method: 'DELETE'
  })
}

/**
 * Handle Task
 * @param taskId
 * @returns
 */
export function handleTask(taskId) {
  return request({
    url: `/task/handle/${taskId}`,
    method: 'PUT'
  })
}

/**
 * Transfer Task
 * @param data
 * @returns
 */
export function transferTask(data) {
  return request({
    url: `/task/transfer`,
    method: 'PUT',
    data
  })
}

/**
 * Cancel Task
 * @param taskId
 * @returns
 */
export function cancelTask(taskId) {
  return request({
    url: `/task/cancel/${taskId}`,
    method: 'PUT'
  })
}
